#ifndef __MFRASTERIZER_H_
#define __MFRASTERIZER_H_

#ifndef MFRASTERIZERAPI
	#define MFRASTERIZERAPI __stdcall
#endif

//////////////////////////////////////////////////////////////////////////
// MFRasterizer function is designed for the most effective usage of 
// Windows metafiles (WMF, EMF) rasterization library. Metafile descriptor 
// is used as an input parameter. It is also possible to set parameters 
// for the image to be enlarged while being rasterized.
// 
// Returns TRUE if completed successfully. 
//
bool MFRASTERIZERAPI MFRasterizer(
	HDC           hDC,           // Handle to the device context of the rasterized metafile being displayed. 
	HENHMETAFILE  hMetafile,     // Handle to the Windows metafile
	RECT*         pRect,         // Pointer to a RECT structure that contains the coordinates of the bounding rectangle used to display the picture. 
	unsigned char bTransparency, // Transparency index (from 0 to 255, 0 - absolutely transparent image).
	double        dAngle,        // Radian angle of image rotation.
	double        dX1,           // Coordinate of metafile left upper corner for the purpose of rasterization (relative units, from 0 to 1). Used for images scaling. 
	double        dY1,           // 
	double        dX2,           // Coordinate of metafile right down corner for the purpose of rasterization (relative units, from 0 to 1). Used for images scaling. 
	double        dY2            // 
);


//////////////////////////////////////////////////////////////////////////
// Purpose of MFRasterizerFile function is to provide simple and quality 
// Windows metafiles (WMF, EMF) rasterization in your programs. Input 
// parameters of the function are rasterization parameters and full path 
// to metafile. 
//
// Returns TRUE if completed successfully.
//
bool MFRASTERIZERAPI MFRasterizerFile(
	HDC           hDC,           // Handle to the device context of the rasterized metafile being displayed. 
	char*         pcFilename,    // Path to metafile (ANSI encoding). 
	RECT*         pRect,         // Pointer to a RECT structure that contains the coordinates of the bounding rectangle used to display the picture. 
	unsigned char bTransparency, // Transparency index (from 0 to 255, 0 - absolutely transparent image).
	bool          bProp,         // Proportionality tag. If TRUE is chosen than image is going to be rasterized according to ratio of its' sizes.
	double        dAngle         // Radian angle of image rotation.
);

bool MFRASTERIZERAPI MFRasterizerFileW(
	HDC           hDC,           // Handle to the device context of the rasterized metafile being displayed. 
	wchar_t*      pwcFilename,   // Path to metafile (UNICODE encoding).
	RECT*         pRect,         // Pointer to a RECT structure that contains the coordinates of the bounding rectangle used to display the picture.
	unsigned char bTransparency, // Transparency index (from 0 to 255, 0 - absolutely transparent image).
	bool          bProp,         // Proportionality tag. If TRUE is chosen than image is going to be rasterized according to ratio of its' sizes.
	double        dAngle         // Radian angle of image rotation.
);

#endif
